pype32.datatypes.DWORD

Package pype32 :: Module datatypes :: Class DWORD |
[hide private]
[frames] | no frames]

# Class DWORD

source code

                       object --+
                                |
    baseclasses.DataTypeBaseClass --+
                                    |
                                   DWORD

Dword object.

Instance Methods | [hide private]
__init__(self, value=0, endianness=`'``<``'`, signed=False, shouldPack=True) x.__init__(...) initializes x; see help(type(x)) for signature | source code
__str__(self) str(x) | source code
__len__(self) | source code
getType(self) Returns TYPE_DWORD. | source code
sizeof(self) Returns the size of DWORD. | source code
Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__subclasshook__`
Inherited from baseclasses.DataTypeBaseClass
__add__(self, other) | source code
__and__(self, other) | source code
__div__(self, other) | source code
__eq__(self, other) | source code
__ge__(self, other) | source code
__gt__(self, other) | source code
__le__(self, other) | source code
__lshift__(self, other) | source code
__lt__(self, other) | source code
__mul__(self, other) | source code
__ne__(self, other) | source code
__or__(self, other) | source code
__rshift__(self, other) | source code
__sub__(self, other) | source code
__xor__(self, other) | source code

Static Methods | [hide private]
DWORD |
parse(readDataInstance) Returns a new DWORD object. | source code

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, value=0, endianness=`'``<``'`, signed=False, shouldPack=True) (Constructor) | source code
x.__init__(...) initializes x; see help(type(x)) for signature Parameters: `value` - The value used to build the BYTE object. `endianness` - (Optional) Indicates the endianness of the BYTE object. The `<` indicates little-endian while `>` indicates big-endian. `signed` - (Optional) If set to `True` the BYTE object will be packed as signed. If set to `False` it will be packed as unsigned. `shouldPack` - (Optional) If set to c{True}, the object will be packed. If set to `False`, the object won't be packed. Overrides: object.__init__ (inherited documentation)

### __str__(self) (Informal representation operator) | source code
str(x) Overrides: object.__str__ (inherited documentation)

### parse(readDataInstance) Static Method | source code
Returns a new DWORD object. Parameters: `readDataInstance` (ReadData) - A ReadData object with the necessary data to build a new DWORD object. Returns: DWORD A new DWORD object.